@@ -10,14 +10,18 @@ import re
 from datetime import timedelta
 
 
-VERSION = "1.0.0"
+VERSION = "1.0.1+"
 
 
 regex = re.compile(r'^((?P<weeks>[\.\d]+?)w)? *'
-                   r'^((?P<days>[\.\d]+?)d)? *'
+                   r'((?P<days>[\.\d]+?)d)? *'
                    r'((?P<hours>[\.\d]+?)h)? *'
                    r'((?P<minutes>[\.\d]+?)m)? *'
-                   r'((?P<seconds>[\.\d]+?)s)?$')
+                   r'((?P<seconds>[\.\d]+?)s?)?$')
+
+
+class TimeFormatError(ValueError):
+    pass
 
 
 def parse_time(time_str):
@@ -31,8 +35,11 @@ def parse_time(time_str):
     :return datetime.timedelta: A datetime.timedelta object
     """
     parts = regex.match(time_str)
-    assert parts is not None, """Could not parse any time information from '{}'.
-    Examples of valid strings: '8h', '2d 8h 5m 2s', '2m4.3s'""".format(time_str)
+    if parts is None:
+        raise TimeFormatError(
+            "Could not parse any time information from '%s'. "
+            "Examples of valid strings: "
+            "'8h', '2d 8h 5m 2s', '2m4.3s'""" % time_str)
     time_params = {name: float(param)
                    for name, param in parts.groupdict().items() if param}
     return timedelta(**time_params)
